@@ -19,7 +19,7 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
 
     nodes = [node(i, device) for i in range(num_nodes)]
     # local_models = [model() for i in range(num_nodes)]
-    local_loss = [objective() for i in range(num_nodes)]
+    # local_loss = [objective() for i in range(num_nodes)]
 
     for i in range(num_nodes):
         # data
@@ -29,9 +29,11 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
         # model
         # nodes[i].assign_model(local_models[i])
         # objective
-        nodes[i].assign_objective(local_loss[i])
+        nodes[i].assign_objective(objective())
         # optim
         # nodes[i].assign_optim(optimizer(model().parameters()))
+    
+    del train_splited, test_splited
 
     # initialize parameters to nodes
     # server.distribute(nodes, list(range(num_nodes)))
@@ -69,7 +71,7 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
             if len(assignment[k])>0:
                 server.aggregate(nodes, assignment[k])
                 server.distribute(nodes, assignment[k])
-                cluster_models[k] = server.model
+                cluster_models[k].load_state_dict(server.model.state_dict())
 
         # test accuracy
         for i in range(num_nodes):
@@ -77,7 +79,9 @@ def run(dataset_splited, batch_size, K, num_nodes, model, objective, optimizer,
         server.acc(nodes, list(range(num_nodes)))
 
     # log
-    if not reg:
+    if reg:
         log(os.path.basename(__file__)[:-3] + '_' + str(K) + '_' + str(reg) + '_' + split_para, nodes, server)
     else:
-        log(os.path.basename(__file__)[:-3] + '_' + str(K) + '_' + split_para, nodes, server)
\ No newline at end of file
+        log(os.path.basename(__file__)[:-3] + '_' + str(K) + '_' + split_para, nodes, server)
+
+    return cluster_models
\ No newline at end of file
